@@ -1,39 +1,43 @@
 import argparse
-import locale
 import sys
 
+from . import __version__
 from .fa_scrapper import (
-    FACategory,
+    FILM_FIELDNAMES,
+    LIST_FIELDNAMES,
     get_list_data,
     get_profile_data,
     save_lists_to_csv,
     save_to_csv,
-    set_locale,
 )
-
-__version__ = "0.1.1"
+from .types import FACategory, Lang, ListId, UserId
 
 
 def main():
     """Main function"""
     parser = argparse.ArgumentParser(
-        description="Generates Letterboxd-compatible csv from Filmaffinity user data."
+        description="Generates Letterboxd-compatible csv from Filmaffinity user data.",
+        prog="fa-scrapper",
     )
-    parser.add_argument("id", help="User id")
-    parser.add_argument("--list", help="List id", metavar="LIST")
-    parser.add_argument("--csv", nargs=1, help="Name of export FILE", metavar="FILE")
+    parser.add_argument("id", help="user id", type=UserId)
+    parser.add_argument("--list", help="list id", metavar="LIST", type=ListId)
+    parser.add_argument("--csv", nargs=1, help="name of export FILE", metavar="FILE")
     parser.add_argument(
         "--lang",
         nargs=1,
-        help="Language for exporting",
+        help="language for exporting",
+        type=Lang,
         metavar="LANG",
-        default=["en"],
-        choices={"es", "en"},
+        default=[Lang.EN],
+        choices=Lang,
+    )
+    parser.add_argument("--all-lists", action="store_true", help="download all lists")
+    parser.add_argument(
+        "--version", action="version", version="%(prog)s {}".format(__version__)
     )
-    parser.add_argument("--all-lists", action="store_true", help="Download all lists")
     parser.add_argument(
         "--ignore",
-        help="Ignore a category (TVS/TVMS/TV/S). This can be used multiple times. By default, all categories are included.",
+        help="ignore category (default: all)",
         type=FACategory,
         choices=FACategory,
         action="append",
@@ -57,32 +61,18 @@ def main():
             id=args.id, lang=args.lang[0]
         )
 
-    try:
-        set_locale(args.lang[0])
-    except locale.Error:
-        print(
-            "Could not set locale for '{lang}' and UTF-8 encoding.".format(
-                lang=args.lang[0]
-            )
-        )
-        manual_locale = input("locale (empty for default): ").strip()
-        if manual_locale:
-            try:
-                locale.setlocale(locale.LC_ALL, manual_locale)
-            except locale.Error as e:
-                print(e)
-                sys.exit()
-
     if args.all_lists:
         save_lists_to_csv(args.id, args.lang[0], export_file, args.ignore)
     else:
         try:
             if args.list:
                 data = get_list_data(args.id, args.list, args.lang[0], args.ignore)
+                fieldnames = LIST_FIELDNAMES
             else:
                 data = get_profile_data(args.id, args.lang[0], args.ignore)
+                fieldnames = FILM_FIELDNAMES
         except ValueError as v:
             print("Error:", v)
             sys.exit()
 
-        save_to_csv(data, export_file)
+        save_to_csv(data, fieldnames, export_file)
